==> haskell-zeromq4-haskell-0.8.0-147.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-zeromq4-haskell.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                   zeromq4-haskell
version:                0.8.0
visibility:             public
id:                     zeromq4-haskell-0.8.0-ChCGqWfwfEcNKZlf5SSRg
key:                    zeromq4-haskell-0.8.0-ChCGqWfwfEcNKZlf5SSRg
license:                MIT
copyright:              (c) 2010 - 2015 zeromq-haskell authors
maintainer:             Toralf Wittner <tw@dtex.org>
author:                 Toralf Wittner
stability:              experimental
homepage:               https://gitlab.com/twittner/zeromq-haskell/
synopsis:               Bindings to ZeroMQ 4.x
description:
    The 0MQ lightweight messaging kernel is a library which extends
    the standard socket interfaces with features traditionally provided
    by specialised messaging middleware products.

    0MQ sockets provide an abstraction of asynchronous message queues,
    multiple messaging patterns, message filtering (subscriptions),
    seamless access to multiple transport protocols and more.

    This library provides the Haskell language binding to 0MQ >= 4.x

category:               System, FFI
abi:                    fd4a9248c0269ff305e3860e6c90d152
exposed:                True
exposed-modules:
    Data.Restricted System.ZMQ4 System.ZMQ4.Internal
    System.ZMQ4.Internal.Base System.ZMQ4.Internal.Error
    System.ZMQ4.Monadic

import-dirs:            /usr/lib/ghc-9.6.6/site-local/zeromq4-haskell-0.8.0
library-dirs:
    /usr/lib/ghc-9.6.6/site-local/zeromq4-haskell-0.8.0 /usr/lib

library-dirs-static:
    /usr/lib/ghc-9.6.6/site-local/zeromq4-haskell-0.8.0 /usr/lib

dynamic-library-dirs:   /usr/lib /usr/lib
data-dir:               /usr/share/haskell-zeromq4-haskell
hs-libraries:           HSzeromq4-haskell-0.8.0-ChCGqWfwfEcNKZlf5SSRg
extra-libraries:        zmq
extra-libraries-static:
    zmq stdc++ rt gnutls gmp unistring atomic hogweed gmp nettle tasn1
    idn2 unistring p11-kit leancrypto sodium pthread pgm m

include-dirs:
    /usr/include /usr/include/p11-kit-1 /usr/include/pgm-5.3

depends:
    async-2.2.5-1Z88VuXAsSjFYCStMD3XFv base-4.18.2.1
    bytestring-0.11.5.3 containers-0.6.7 exceptions-0.10.7
    monad-control-1.0.3.1-JNSSe1yK184K4km57LK5G2 transformers-0.6.1.0
    transformers-base-0.4.6-IFFPlbMue7bJmNu16qahDQ

haddock-interfaces:
    /usr/share/doc/haskell-zeromq4-haskell/html/zeromq4-haskell.haddock

haddock-html:           /usr/share/doc/haskell-zeromq4-haskell/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-zeromq4-haskell-0.8.0-148-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-zeromq4-haskell.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                   zeromq4-haskell
version:                0.8.0
visibility:             public
id:                     zeromq4-haskell-0.8.0-FkThmOtI74XafZt2ovDui
key:                    zeromq4-haskell-0.8.0-FkThmOtI74XafZt2ovDui
license:                MIT
copyright:              (c) 2010 - 2015 zeromq-haskell authors
maintainer:             Toralf Wittner <tw@dtex.org>
author:                 Toralf Wittner
stability:              experimental
homepage:               https://gitlab.com/twittner/zeromq-haskell/
synopsis:               Bindings to ZeroMQ 4.x
description:
    The 0MQ lightweight messaging kernel is a library which extends
    the standard socket interfaces with features traditionally provided
    by specialised messaging middleware products.

    0MQ sockets provide an abstraction of asynchronous message queues,
    multiple messaging patterns, message filtering (subscriptions),
    seamless access to multiple transport protocols and more.

    This library provides the Haskell language binding to 0MQ >= 4.x

category:               System, FFI
abi:                    289c58cac6afe759cfe786d001b0f71c
exposed:                True
exposed-modules:
    Data.Restricted System.ZMQ4 System.ZMQ4.Internal
    System.ZMQ4.Internal.Base System.ZMQ4.Internal.Error
    System.ZMQ4.Monadic

import-dirs:            /usr/lib/ghc-9.6.6/site-local/zeromq4-haskell-0.8.0
library-dirs:
    /usr/lib/ghc-9.6.6/site-local/zeromq4-haskell-0.8.0 /usr/lib

library-dirs-static:
    /usr/lib/ghc-9.6.6/site-local/zeromq4-haskell-0.8.0 /usr/lib

dynamic-library-dirs:   /usr/lib /usr/lib
data-dir:               /usr/share/haskell-zeromq4-haskell
hs-libraries:           HSzeromq4-haskell-0.8.0-FkThmOtI74XafZt2ovDui
extra-libraries:        zmq
extra-libraries-static:
    zmq stdc++ rt gnutls gmp unistring atomic hogweed gmp nettle tasn1
    idn2 unistring p11-kit leancrypto sodium pthread pgm m

include-dirs:
    /usr/include /usr/include/p11-kit-1 /usr/include/pgm-5.3

depends:
    async-2.2.5-6z3frWRfGJJLLgOv3gEskc base-4.18.2.1
    bytestring-0.11.5.3 containers-0.6.7 exceptions-0.10.7
    monad-control-1.0.3.1-JNSSe1yK184K4km57LK5G2 transformers-0.6.1.0
    transformers-base-0.4.6-IFFPlbMue7bJmNu16qahDQ

haddock-interfaces:
    /usr/share/doc/haskell-zeromq4-haskell/html/zeromq4-haskell.haddock

haddock-html:           /usr/share/doc/haskell-zeromq4-haskell/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
